pub enum ElfError {
TooShort,
BadMagic,
Not32Bit,
WrongEndian,
NotRiscV,
InvalidProgramHeader,
InvalidSectionHeader,
}Variants
TooShort
File is too short to contain an ELF header.
BadMagic
Magic bytes (\x7fELF) do not match.
Not32Bit
ELF class is not 32-bit.
WrongEndian
ELF data encoding is not little-endian.
NotRiscV
e_machine is not EM_RISCV (243).
InvalidProgramHeader
A program header is out of bounds or overflows.
InvalidSectionHeader
A section header is out of bounds or overflows.